import { Chain, LayoutToType, Network, Platform, PlatformToChains } from "@wormhole-foundation/sdk-base";
import { AccountAddress, ChainAddress } from "../address";
import { CircleMessageId } from "../attestation";
import "../payloads/connect";
import { TokenId } from "../types";
import { UnsignedTransaction } from "../unsignedTransaction";
export declare const circleMessageLayout: readonly [{
    readonly binary: "uint";
    readonly size: 4;
    readonly custom: 0;
    readonly omit: true;
    readonly name: "version";
}, {
    readonly binary: "uint";
    readonly size: 4;
    readonly custom: {
        readonly to: (id: number) => "Ethereum" | "Avalanche" | "Optimism" | "Arbitrum" | "Base" | "Solana" | "Terra" | "Bsc" | "Polygon" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Sepolia";
        readonly from: (name: "Ethereum" | "Avalanche" | "Optimism" | "Arbitrum" | "Base") => 0 | 2 | 1 | 3 | 6;
    };
    readonly name: "sourceDomain";
}, {
    readonly binary: "uint";
    readonly size: 4;
    readonly custom: {
        readonly to: (id: number) => "Ethereum" | "Avalanche" | "Optimism" | "Arbitrum" | "Base" | "Solana" | "Terra" | "Bsc" | "Polygon" | "Oasis" | "Algorand" | "Aurora" | "Fantom" | "Karura" | "Acala" | "Klaytn" | "Celo" | "Near" | "Moonbeam" | "Neon" | "Terra2" | "Injective" | "Osmosis" | "Sui" | "Aptos" | "Gnosis" | "Pythnet" | "Xpla" | "Btc" | "Sei" | "Rootstock" | "Wormchain" | "Cosmoshub" | "Evmos" | "Kujira" | "Sepolia";
        readonly from: (name: "Ethereum" | "Avalanche" | "Optimism" | "Arbitrum" | "Base") => 0 | 2 | 1 | 3 | 6;
    };
    readonly name: "destinationDomain";
}, {
    readonly binary: "uint";
    readonly size: 8;
    readonly name: "nonce";
}, {
    readonly binary: "bytes";
    readonly size: 32;
    readonly custom: {
        to: (val: Uint8Array) => import("..").UniversalAddress;
        from: (val: import("..").UniversalAddress) => Uint8Array;
    };
    readonly name: "sender";
}, {
    readonly binary: "bytes";
    readonly size: 32;
    readonly custom: {
        to: (val: Uint8Array) => import("..").UniversalAddress;
        from: (val: import("..").UniversalAddress) => Uint8Array;
    };
    readonly name: "recipient";
}, {
    readonly binary: "bytes";
    readonly size: 32;
    readonly custom: {
        to: (val: Uint8Array) => import("..").UniversalAddress;
        from: (val: import("..").UniversalAddress) => Uint8Array;
    };
    readonly name: "destinationCaller";
}, {
    readonly name: "payload";
    readonly binary: "object";
    readonly layout: readonly [{
        readonly binary: "uint";
        readonly size: 4;
        readonly custom: 0;
        readonly omit: true;
        readonly name: "messageBodyVersion";
    }, {
        readonly binary: "bytes";
        readonly size: 32;
        readonly custom: {
            to: (val: Uint8Array) => import("..").UniversalAddress;
            from: (val: import("..").UniversalAddress) => Uint8Array;
        };
        readonly name: "burnToken";
    }, {
        readonly binary: "bytes";
        readonly size: 32;
        readonly custom: {
            to: (val: Uint8Array) => import("..").UniversalAddress;
            from: (val: import("..").UniversalAddress) => Uint8Array;
        };
        readonly name: "mintRecipient";
    }, {
        readonly binary: "uint";
        readonly size: 32;
        readonly name: "amount";
    }, {
        readonly binary: "bytes";
        readonly size: 32;
        readonly custom: {
            to: (val: Uint8Array) => import("..").UniversalAddress;
            from: (val: import("..").UniversalAddress) => Uint8Array;
        };
        readonly name: "messageSender";
    }];
}];
export declare const deserializeCircleMessage: (data: Uint8Array) => [LayoutToType<typeof circleMessageLayout>, string];
export type CircleTransferMessage = {
    from: ChainAddress;
    to: ChainAddress;
    token: TokenId;
    amount: bigint;
    messageId: CircleMessageId;
};
export interface AutomaticCircleBridge<N extends Network, P extends Platform, C extends Chain = PlatformToChains<P>> {
    getRelayerFee(destination: Chain): Promise<bigint>;
    transfer(sender: AccountAddress<C>, recipient: ChainAddress, amount: bigint, nativeGas?: bigint): AsyncGenerator<UnsignedTransaction<N, C>>;
}
export interface CircleBridge<N extends Network, P extends Platform, C extends PlatformToChains<P>> {
    redeem(sender: AccountAddress<C>, message: string, attestation: string): AsyncGenerator<UnsignedTransaction<N, C>>;
    transfer(sender: AccountAddress<C>, recipient: ChainAddress, amount: bigint): AsyncGenerator<UnsignedTransaction<N, C>>;
    parseTransactionDetails(txid: string): Promise<CircleTransferMessage>;
}
//# sourceMappingURL=cctp.d.ts.map